# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import gettext_lazy as _
from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin

from . import models


class LanguageAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('code__icontains', 'name__icontains',),
        ('country__icontains', 'nationality__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'country', 'nationality',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('code', 'status', 'name', 'country', 'nationality', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')


admin.site.register(models.Language, LanguageAdmin)
