# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _
from thx.core.models import CleanModel, DateModel, OrderedModel, StatusModel, UserModel


class LanguageModel(models.Model):
    """
    **LanguageModel** è una classe *abstract* che estende django.db.models.Model.

    Alla classe erede viene aggiunto un attributo:

    - language: indica la lingua di un record e i valori sono limitati dal settings LANGUAGES
    """
    language = models.CharField(
        max_length=255,
        choices=settings.LANGUAGES,
        default=settings.LANGUAGE_CODE,
        verbose_name=_('language')
    )

    class Meta:
        abstract = True


class Language(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        primary_key=True,
        max_length=2,
        verbose_name=_('ISO language code'),
    )
    name = models.CharField(
        max_length=20,
        verbose_name=_('name'),
    )
    country = models.CharField(
        max_length=20,
        verbose_name=_('country'),
    )
    nationality = models.CharField(
        max_length=20,
        verbose_name=_('nationality'),
    )

    class Meta:
        verbose_name = _('language')
        verbose_name_plural = _('languages')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_language", "Can list language"),
            ("detail_language", "Can detail language"),
            ("enable_language", "Can enable language"),
            ("disable_language", "Can disable language"),
        )

    def __str__(self):
        return self.name
